import {
    Dropdown,
    DropdownItem,
    DropdownMenu,
    DropdownSection,
    DropdownTrigger,
} from "@nextui-org/react";
import React, { useState } from "react";
import { AcmeIcon } from "../icons/acme-icon";
import { AcmeLogo } from "../icons/acmelogo";
import { BottomIcon } from "../icons/sidebar/bottom-icon";
import { router, usePage, Link } from "@inertiajs/react";

interface Company {
    name: string;
    location: string;
    logo: React.ReactNode;
}

export const CompaniesDropdown = () => {
    const [company, setCompany] = useState<Company>({
        name: "",
        location: "",
        logo: (
            <Link href="/">
                <div className="h-14 w-32 text-primary-500 group-hover:text-primary-500 transition-colors duration-300">
                    <img src="/logo.png" className="w-full h-full" />
                </div>
            </Link>
        ),
    });
    return (
        <Dropdown
            classNames={{
                base: "w-full min-w-[260px]",
            }}
        >
            <DropdownTrigger className="cursor-pointer">
                <div className="flex items-center gap-2">
                    {/* */}
                    {company.logo}
                    <Link href="/" className="flex flex-col gap-4">
                        <h3 className="text-xl font-medium m-0 text-default-900 -mb-4 whitespace-nowrap">
                            {company.name}
                        </h3>
                        <span className="text-xs font-medium text-default-500">
                            {company.location}
                        </span>
                    </Link>
                    {/* */}
                    <BottomIcon />
                </div>
            </DropdownTrigger>
            <DropdownMenu onAction={(e) => {}} aria-label="Avatar Actions">
                <DropdownSection title="Scan To Download Mobile App">
                    <DropdownItem
                        key="1"
                        description="Mobile App"
                        className=" flex items-center justify-center  "
                        classNames={{
                            base: "mx-auto flex items-center justify-center  ",
                            title: "text-base text-center font-semibold",
                            description: "text-center",
                        }}
                    >
                        <div className="flex items-center justify-center w-full">
                            <img
                                src="/img/bg/qr.png"
                                className="object-cover h-32 w-32"
                            />
                        </div>
                    </DropdownItem>
                </DropdownSection>
            </DropdownMenu>
        </Dropdown>
    );
};
